/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import uiRoutes from 'ui/routes';
import template from './index.html';

require('brace');

require('ui/autoload/styles');
require('ui/capabilities/route_setup');

require('./src/controllers/sense_controller');
require('./src/directives/sense_history');
require('./src/directives/console_menu_directive');


uiRoutes.when('/dev_tools/console', {
  requireUICapability: 'dev_tools.show',
  controller: 'SenseController',
  template,
});
